pub async fn voice_join_req(
configuration: &Configuration,
target: &str,
) -> Result<CreateVoiceUserResponse, Error<VoiceJoinReqError>>Expand description
Asks the voice server for a token to join the call.
pub async fn voice_join_req(
configuration: &Configuration,
target: &str,
) -> Result<CreateVoiceUserResponse, Error<VoiceJoinReqError>>Asks the voice server for a token to join the call.