pub struct BotInformation {
pub owner: String,
}Expand description
BotInformation : Bot information for if the user is a bot
Fields
owner: StringId of the owner of this bot
Implementations
Sourceimpl BotInformation
impl BotInformation
Sourcepub fn new(owner: String) -> BotInformation
pub fn new(owner: String) -> BotInformation
Bot information for if the user is a bot