pub struct MessageInteractions {
pub reactions: Option<Option<Vec<String>>>,
pub restrict_reactions: Option<bool>,
}Expand description
MessageInteractions : Information about how this message should be interacted with
Fields
reactions: Option<Option<Vec<String>>>Reactions which should always appear and be distinct
restrict_reactions: Option<bool>Whether reactions should be restricted to the given list Can only be set to true if reactions list is of at least length 1
Implementations
Sourceimpl MessageInteractions
impl MessageInteractions
Sourcepub fn new() -> MessageInteractions
pub fn new() -> MessageInteractions
Information about how this message should be interacted with