ChannelOneOf2

Struct ChannelOneOf2 

pub struct ChannelOneOf2 {
    pub channel_type: ChannelType,
    pub _id: String,
    pub name: String,
    pub owner: String,
    pub description: Option<Option<String>>,
    pub recipients: Vec<String>,
    pub icon: Option<Option<Box<ChannelOneOf2Icon>>>,
    pub last_message_id: Option<Option<String>>,
    pub permissions: Option<Option<i64>>,
    pub nsfw: Option<bool>,
}
ChannelOneOf2 : Group channel between 1 or more participants

Fields

channel_type: ChannelType_id: String

Unique Id

name: String

Display name of the channel

owner: String

User id of the owner of the group

description: Option<Option<String>>

Channel description

recipients: Vec<String>

Array of user ids participating in channel

icon: Option<Option<Box<ChannelOneOf2Icon>>>last_message_id: Option<Option<String>>

Id of the last message sent in this channel

permissions: Option<Option<i64>>

Permissions assigned to members of this group (does not apply to the owner of the group)

nsfw: Option<bool>

Whether this group is marked as not safe for work

Implementations

Source

impl ChannelOneOf2

pub fn new( channel_type: ChannelType, _id: String, name: String, owner: String, recipients: Vec<String>, ) -> ChannelOneOf2

Group channel between 1 or more participants